@@ -52,6 +52,7 @@ package com.openexchange.filestore.sproxyd;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.HashSet;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Set;
 import java.util.SortedSet;
@@ -95,7 +96,11 @@ public class SproxydFileStorage implements FileStorage {
     public String saveNewFile(InputStream file) throws OXException {
         try {
             UUID documentId = UUID.randomUUID();
-            upload(documentId, file, 0);
+            long length = upload(documentId, file, 0);
+            if (length <= 0) {
+                // Received an empty input stream
+                throw SproxydExceptionCode.UNEXPECTED_ERROR.create("Sproxyd storage cannot save an empty file");
+            }
             return UUIDs.getUnformattedString(documentId);
         } finally {
             Streams.close(file);
@@ -143,9 +148,15 @@ public class SproxydFileStorage implements FileStorage {
     @Override
     public boolean deleteFile(String identifier) throws OXException {
         UUID documentId = UUIDs.fromUnformattedString(identifier);
-        List<Chunk> chunks = chunkStorage.getChunks(documentId);
-        if (null != chunks && 0 < chunks.size()) {
-            List<UUID> scalityIds = new ArrayList<UUID>(chunks.size());
+        List<Chunk> chunks = chunkStorage.optChunks(documentId);
+        if (null != chunks) {
+            int size = chunks.size();
+            if (0 >= size) {
+                // Apparently no such document exists; consider as deleted
+                return true;
+            }
+
+            List<UUID> scalityIds = new ArrayList<UUID>(size);
             for (Chunk chunk : chunks) {
                 scalityIds.add(chunk.getScalityId());
             }
@@ -286,21 +297,54 @@ public class SproxydFileStorage implements FileStorage {
     private long upload(UUID documentId, InputStream data, long offset) throws OXException {
         boolean success = false;
         DefaultChunkedUpload chunkedUpload = null;
-        List<UUID> scalityIds = new ArrayList<UUID>();
+        List<UUID> scalityIds = new LinkedList<UUID>();
         try {
             chunkedUpload = new DefaultChunkedUpload(data);
             long off = offset;
-            while (chunkedUpload.hasNext()) {
+            if (!chunkedUpload.hasNext()) {
+                success = true;
+                return off;
+            }
+
+            // Handle first chunk especially
+            {
                 UploadChunk chunk = chunkedUpload.next();
                 try {
-                    UUID scalityId = client.put(chunk.getData(), chunk.getSize());
+                    // ... and upload first chunk
+                    long chunkSize = chunk.getSize();
+                    UUID scalityId = client.put(chunk.getData(), chunkSize);
                     scalityIds.add(scalityId);
-                    chunkStorage.storeChunk(new Chunk(documentId, scalityId, off, chunk.getSize()));
+                    chunkStorage.storeChunk(new Chunk(documentId, scalityId, off, chunkSize));
+
+                    if (chunkSize <= 0) {
+                        // Received an empty input stream
+                        success = true;
+                        return off;
+                    }
+
                     off += chunk.getSize();
                 } finally {
                     Streams.close(chunk);
                 }
             }
+
+            // Handle remaining chunks
+            while (chunkedUpload.hasNext()) {
+                UploadChunk chunk = chunkedUpload.next();
+                try {
+                    long chunkSize = chunk.getSize();
+                    if (chunkSize > 0) {
+                        UUID scalityId = client.put(chunk.getData(), chunk.getSize());
+                        scalityIds.add(scalityId);
+                        chunkStorage.storeChunk(new Chunk(documentId, scalityId, off, chunk.getSize()));
+                        off += chunk.getSize();
+                    }
+                } finally {
+                    Streams.close(chunk);
+                }
+            }
+
+            // All fine, no error occurred
             success = true;
             return off;
         } finally {
